aboutsummaryrefslogtreecommitdiff
path: root/sound/audiostream.h
diff options
context:
space:
mode:
authorMax Horn2010-01-08 22:06:04 +0000
committerMax Horn2010-01-08 22:06:04 +0000
commit474d49946f5254bff7ac6a490fcc3b02655fae23 (patch)
tree127da7f0a99049771e33e60417359fafe9ee77d6 /sound/audiostream.h
parent7efba850648777d2d562bfccf2f14868816d6391 (diff)
downloadscummvm-rg350-474d49946f5254bff7ac6a490fcc3b02655fae23.tar.gz
scummvm-rg350-474d49946f5254bff7ac6a490fcc3b02655fae23.tar.bz2
scummvm-rg350-474d49946f5254bff7ac6a490fcc3b02655fae23.zip
Rename QueuedAudioStream to QueuingAudioStream
svn-id: r47179
Diffstat (limited to 'sound/audiostream.h')
-rw-r--r--sound/audiostream.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/sound/audiostream.h b/sound/audiostream.h
index 7ffbeab5cb..192dc249bf 100644
--- a/sound/audiostream.h
+++ b/sound/audiostream.h
@@ -320,7 +320,7 @@ public:
AppendableAudioStream *makeAppendableAudioStream(int rate, byte flags);
-class QueuedAudioStream : public Audio::AudioStream {
+class QueuingAudioStream : public Audio::AudioStream {
public:
/**
@@ -359,9 +359,9 @@ public:
};
/**
* Factory function for an QueuedAudioStream.
*/
-QueuedAudioStream *makeQueuedAudioStream(int rate, bool stereo);
+QueuingAudioStream *makeQueuingAudioStream(int rate, bool stereo);
/**
@@ -359,9 +359,9 @@ public:
};
/**
- * Factory function for an QueuedAudioStream.
+ * Factory function for an QueuingAudioStream.
*/